@@ -19,7 +19,7 @@ use constant {
     HEADERS_AS_ARRAYREF =>2,    # Ordered ArrayRef : [ name, value, name2, value2 ... ]
 };
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 our $BACKEND;
 
@@ -131,6 +131,8 @@ given request is incomplete
 
 =back
 
+Note that the semantics of PATH_INFO is somewhat different from Apache.  First, L<HTTP::Parser::XS> does not validate the variable; it does not raise an error even if PATH_INFO does not start with "/".  Second, the variable is conformant to RFC 3875 (and L<PSGI> / L<Plack>) in the fact that "//" and ".." appearing in PATH_INFO are preserved whereas Apache transcodes them.
+
 =item parse_http_response($response_string, $header_format, \%special_headers)
 
 Tries to parse given response string. I<$header_format> must be
@@ -224,8 +226,13 @@ charsbar
 L<http://github.com/kazuho/picohttpparser>
 
 L<HTTP::Parser>
+
 L<HTTP::HeaderParser::XS>
 
+L<Plack>
+
+L<PSGI>
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
